Struct PublicKey

pub struct PublicKey<T, const N: usize>(pub(crate) [u8; N], pub(crate) PhantomData<T>);
A public key base type

Tuple Fields

0: [u8; N]1: PhantomData<T>

Implementations

Source

impl PublicKey<Ecdsa, UNCOMPRESSED_PUB_KEY_SIZE>

pub const COMPRESSED_SIZE: usize = 33usize

The size of a compressed ECDSA public key in bytes.

pub fn uncompressed(&self) -> [u8; 65]

Returns the uncompressed public key as a byte array.

pub fn compressed(&self) -> [u8; 33]

Returns the compressed public key as a byte array.

Source

impl PublicKey<Ed25519, PUB_KEY_SIZE>

pub const SIZE: usize = 32usize

The size of an Ed25519 public key in bytes.

pub fn as_bytes(&self) -> &[u8; 32]

Returns the public key as a byte array.

pub fn into_bytes(self) -> [u8; 32]

Consumes the public key and returns it as a byte array.

Source

impl PublicKey<Bip340, 32>

pub fn as_bytes(&self) -> &[u8; 32]

Returns the public key as a byte array.